-- get the addon namespace
local addon, ns = ...
-- get the config values
local cfg = ns.cfg
-- holder for some lib functions
local lib = _G["HEDD_lib"] or CreateFrame("Frame","HEDD_lib")
ns.lib = lib

lib.InitCleave = function(threshold)
	threshold=threshold or 3
	if cfg.debugcleave then
		print("InitCleave")
	end
	if cfg.Cleave then
		threshold=cfg.Cleave.threshold or threshold
	end
	cfg.Cleave={}
	cfg.Cleave.threshold=threshold
	cfg.Cleave.cast_time=0
	cfg.Cleave.hit_time=0
	cfg.Cleave.num=0
	cfg.Cleave.targets={}
	cfg.Cleave.current="NoSpell"
end

lib.AddCleaveSpell = function(spell,threshold,spellid)
	if not cfg.spells[spell] then return end
	if not cfg.Cleave then
		lib.InitCleave()
	end
	
	cfg.Cleave.threshold=threshold or cfg.Cleave.threshold
	cfg.Cleave.threshold=cfg.Cleave.threshold
	for index,id in ipairs(cfg.spells[spell].clone) do
		cfg.Id2Cleave[id]=spell
	end
	localspells=table.concat(cfg.spells[spell].clone,", ")
	if spellid then
		if type(spellid)=="number" then
			spellid = {spellid}
		end
		for index,id in ipairs(spellid) do
			cfg.Id2Cleave[id]=spell
			localspells=localspells..", "..id
		end
	end
	
	if cfg.debugcleave then
		print("Cleave added "..spell.." "..localspells)
	end
end

lib.ResetCleaveAll = function()
	if cfg.Cleave then
		lib.InitCleave()
		lib.UpdateCleave(0,nil,"ResetCleaveAll")
		if cfg.debugcleave then
			print("\124cFFFF0000ResetCleaveAll\124r")
		end
	end
end
lib.ResetCleave=function(spellid,timeStamp)
	lib.InitCleave()
	cfg.Cleave.cast_time = timeStamp or time()
	cfg.Cleave.current=cfg.Id2Cleave[spellid]
	lib.UpdateCleave(0,spellid,"ResetCleave"..cfg.Cleave.current)
	if cfg.debugcleave then
		print("\124cFFFF0000ResetCleave\124r by "..cfg.Cleave.current.." "..spellid)
	end
end

lib.AddCleaveTarget = function(spellid,destGUID,timeStamp,eventtype)
	eventtype=eventtype or "unknown"
	--timeStamp = timeStamp or time()
	if cfg.Cleave.targets[destGUID] then
		--[[if cfg.debugcleave then
			print("Target "..destGUID.." already set")
		end]]
	else
		if cfg.debugcleave then
			print("\124cFF00FF00AddCleaveTarget\124r "..eventtype.." "..cfg.Cleave.current.." "..spellid.." "..destGUID)
		end
		cfg.Cleave.targets[destGUID]=lib.AddNPC(destGUID)
		cfg.Cleave.num=cfg.Cleave.num+1
		lib.UpdateCleave(cfg.Cleave.num,nil,"AddCleaveTarget")
	end
end

lib.RemoveCleaveTarget = function(destGUID)
	if cfg.Cleave.targets[destGUID] then
		if cfg.debugcleave then
			print("\124cFFFF0000RemoveCleaveTarget\124r "..cfg.Cleave.current.." "..destGUID)
		end
		cfg.Cleave.num=cfg.Cleave.num-1
		if cfg.Cleave.num<0 then cfg.Cleave.num=0 end
		lib.UpdateCleave(cfg.Cleave.num,nil,"RemoveCleaveTarget")
	end
end

lib.UpdateCleave=function(targets,spell,event)
	event=event or "unknown"
	targets=targets or 0
	if cfg.debugcleave then
		print("UpdateCleave "..targets.." on "..event)
	end
	if cfg.Cleave.num>1 then
		Heddmain.spells.cleave:SetText(cfg.Cleave.num)
		if cfg.Cleave.num>=cfg.Cleave.threshold then
			Heddmain.spells.cleave:SetTextColor(1,0,0,1)
		else
			Heddmain.spells.cleave:SetTextColor(1,1,1,1)
		end
	else
		--cfg.Cleave.current="NoSpell"
		Heddmain.spells.cleave:SetText("")
	end
	cfg.Update=true
--	end
end
